﻿using System.Text.Json;
using Hotline.FlowEngine.Notifications;
using Hotline.Orders;
using Hotline.Settings;
using MediatR;
using Microsoft.Extensions.Logging;

namespace Hotline.Application.Handlers.FlowEngine
{
    public class StartWorkflowHandler : INotificationHandler<StartWorkflowNotify>
    {
        private readonly IOrderDomainService _orderDomainService;
        private readonly ILogger<StartWorkflowHandler> _logger;

        public StartWorkflowHandler(
            IOrderDomainService orderDomainService,
            ILogger<StartWorkflowHandler> logger)
        {
            _orderDomainService = orderDomainService;
            _logger = logger;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(StartWorkflowNotify notification, CancellationToken cancellationToken)
        {
            _logger.LogInformation($"收到{nameof(StartWorkflowNotify)}, notification: {JsonSerializer.Serialize(notification)}");
            var workflow = notification.Workflow;
            var data = notification.Dto;

            switch (workflow.ModuleCode)
            {
                case WorkflowModuleConsts.OrderManage:
                    await _orderDomainService.ManageFlowNextAsync(notification.FlowAssignMode,
                        notification.IsCountersignStart, false,
                        workflow.ExternalId, workflow.CurrentStepTime, workflow.CurrentStepName, workflow.ExpiredTime, cancellationToken);
                    break;
            }
        }
    }
}
